@@ -4,12 +4,15 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"maps"
 	"math/rand"
 	"net"
+	"slices"
 	"time"
 
 	"github.com/rs/zerolog/log"
 	"github.com/traefik/traefik/v3/pkg/config/runtime"
+	"github.com/traefik/traefik/v3/pkg/healthcheck"
 	"github.com/traefik/traefik/v3/pkg/observability/logs"
 	"github.com/traefik/traefik/v3/pkg/server/provider"
 	"github.com/traefik/traefik/v3/pkg/tcp"
@@ -17,17 +20,19 @@ import (
 
 // Manager is the TCPHandlers factory.
 type Manager struct {
-	dialerManager *tcp.DialerManager
-	configs       map[string]*runtime.TCPServiceInfo
-	rand          *rand.Rand // For the initial shuffling of load-balancers.
+	dialerManager  *tcp.DialerManager
+	configs        map[string]*runtime.TCPServiceInfo
+	rand           *rand.Rand // For the initial shuffling of load-balancers.
+	healthCheckers map[string]*healthcheck.ServiceTCPHealthChecker
 }
 
 // NewManager creates a new manager.
 func NewManager(conf *runtime.Configuration, dialerManager *tcp.DialerManager) *Manager {
 	return &Manager{
-		dialerManager: dialerManager,
-		configs:       conf.TCPServices,
-		rand:          rand.New(rand.NewSource(time.Now().UnixNano())),
+		dialerManager:  dialerManager,
+		healthCheckers: make(map[string]*healthcheck.ServiceTCPHealthChecker),
+		configs:        conf.TCPServices,
+		rand:           rand.New(rand.NewSource(time.Now().UnixNano())),
 	}
 }
 
@@ -51,7 +56,7 @@ func (m *Manager) BuildTCP(rootCtx context.Context, serviceName string) (tcp.Han
 
 	switch {
 	case conf.LoadBalancer != nil:
-		loadBalancer := tcp.NewWRRLoadBalancer()
+		loadBalancer := tcp.NewWRRLoadBalancer(conf.LoadBalancer.HealthCheck != nil)
 
 		if conf.LoadBalancer.TerminationDelay != nil {
 			log.Ctx(ctx).Warn().Msgf("Service %q load balancer uses `TerminationDelay`, but this option is deprecated, please use ServersTransport configuration instead.", serviceName)
@@ -65,6 +70,8 @@ func (m *Manager) BuildTCP(rootCtx context.Context, serviceName string) (tcp.Han
 			conf.LoadBalancer.ServersTransport = provider.GetQualifiedName(ctx, conf.LoadBalancer.ServersTransport)
 		}
 
+		uniqHealthCheckTargets := make(map[string]healthcheck.TCPHealthCheckTarget, len(conf.LoadBalancer.Servers))
+
 		for index, server := range shuffle(conf.LoadBalancer.Servers, m.rand) {
 			srvLogger := logger.With().
 				Int(logs.ServerIndex, index).
@@ -86,14 +93,34 @@ func (m *Manager) BuildTCP(rootCtx context.Context, serviceName string) (tcp.Han
 				continue
 			}
 
-			loadBalancer.AddServer(handler)
+			loadBalancer.Add(server.Address, handler, nil)
+
+			// Servers are considered UP by default.
+			conf.UpdateServerStatus(server.Address, runtime.StatusUp)
+
+			uniqHealthCheckTargets[server.Address] = healthcheck.TCPHealthCheckTarget{
+				Address: server.Address,
+				TLS:     server.TLS,
+				Dialer:  dialer,
+			}
+
 			logger.Debug().Msg("Creating TCP server")
 		}
 
+		if conf.LoadBalancer.HealthCheck != nil {
+			m.healthCheckers[serviceName] = healthcheck.NewServiceTCPHealthChecker(
+				ctx,
+				conf.LoadBalancer.HealthCheck,
+				loadBalancer,
+				conf,
+				slices.Collect(maps.Values(uniqHealthCheckTargets)),
+				serviceQualifiedName)
+		}
+
 		return loadBalancer, nil
 
 	case conf.Weighted != nil:
-		loadBalancer := tcp.NewWRRLoadBalancer()
+		loadBalancer := tcp.NewWRRLoadBalancer(conf.Weighted.HealthCheck != nil)
 
 		for _, service := range shuffle(conf.Weighted.Services, m.rand) {
 			handler, err := m.BuildTCP(ctx, service.Name)
@@ -102,7 +129,25 @@ func (m *Manager) BuildTCP(rootCtx context.Context, serviceName string) (tcp.Han
 				return nil, err
 			}
 
-			loadBalancer.AddWeightServer(handler, service.Weight)
+			loadBalancer.Add(service.Name, handler, service.Weight)
+
+			if conf.Weighted.HealthCheck == nil {
+				continue
+			}
+
+			updater, ok := handler.(healthcheck.StatusUpdater)
+			if !ok {
+				return nil, fmt.Errorf("child service %v of %v not a healthcheck.StatusUpdater (%T)", service.Name, serviceName, handler)
+			}
+
+			if err := updater.RegisterStatusUpdater(func(up bool) {
+				loadBalancer.SetStatus(ctx, service.Name, up)
+			}); err != nil {
+				return nil, fmt.Errorf("cannot register %v as updater for %v: %w", service.Name, serviceName, err)
+			}
+
+			log.Ctx(ctx).Debug().Str("parent", serviceName).Str("child", service.Name).
+				Msg("Child service will update parent on status change")
 		}
 
 		return loadBalancer, nil
@@ -114,6 +159,14 @@ func (m *Manager) BuildTCP(rootCtx context.Context, serviceName string) (tcp.Han
 	}
 }
 
+// LaunchHealthCheck launches the health checks.
+func (m *Manager) LaunchHealthCheck(ctx context.Context) {
+	for serviceName, hc := range m.healthCheckers {
+		logger := log.Ctx(ctx).With().Str(logs.ServiceName, serviceName).Logger()
+		go hc.Launch(logger.WithContext(ctx))
+	}
+}
+
 func shuffle[T any](values []T, r *rand.Rand) []T {
 	shuffled := make([]T, len(values))
 	copy(shuffled, values)
